@@ -1,9 +1,9 @@
 import logging
-from tornado.testing import LogTrapTestCase
+from tornado.testing import ExpectLog
 
 from plop.callgraph import CallGraph, Node
 
-class SimpleCallgraphTest(LogTrapTestCase):
+class SimpleCallgraphTest(ExpectLog):
     def setUp(self):
         graph = CallGraph()
         graph.add_stack([Node(1), Node(2)], dict(time=1))
